#
# spec file for package rssguard
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libver  3_9_2
Name:           rssguard
Version:        3.9.2
Release:        bp153.1.3
Summary:        RSS/ATOM/RDF feed reader
License:        AGPL-3.0-or-later AND GPL-3.0-only
URL:            https://github.com/martinrotter/rssguard
Source0:        https://github.com/martinrotter/rssguard/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{name}.changes
# PATCH-FIX-OPENSUSE rssguard-3.9.0-add_library_version.patch aloisio@gmx.com -- add version to shared library
Patch2:         rssguard-3.9.0-add_library_version.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libqt5-linguist
BuildRequires:  libqt5-qtbase-common-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core) >= 5.12
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5WebEngine)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
Obsoletes:      %{name}-lang < %{version}
Provides:       %{name}-lang = %{version}

%description
RSS Guard is a RSS/ATOM feed aggregator developed using the Qt framework.
It supports online feed synchronization.

%package -n lib%{name}-devel
Summary:        Development headers for lib%{name}-%{libver}
Requires:       lib%{name}-%{libver}

%description -n lib%{name}-devel
Development headers to be used with lib%{name}-%{libver}.

%package -n lib%{name}-%{libver}
Summary:        Shared library for %{name}

%description -n lib%{name}-%{libver}
Shared library for %{name} to be used by external plugins.

%prep
%autosetup -p1
# remove executable bit
chmod -x resources/desktop/com.github.rssguard.appdata.xml
find src/librssguard -name "*.h" -exec chmod -x {} \;

%build
# resources_big is not compatible with LTO
%define _lto_cflags %{nil}
%qmake5 PREFIX=%{_prefix} LIBDIR=%{_libdir} USE_WEBENGINE=true
%make_jobs

%install
%qmake5_install
# install autostart
mkdir -pv %{buildroot}%{_datadir}/autostart
install -m0644 resources/desktop/com.github.%{name}.desktop.autostart -t %{buildroot}%{_datadir}/autostart
%fdupes -s %{buildroot}

%post -n lib%{name}-%{libver} -p /sbin/ldconfig
%postun -n lib%{name}-%{libver} -p /sbin/ldconfig

%files
%license LICENSE.md
%dir %{_datadir}/applications
%dir %{_datadir}/autostart
%dir %{_datadir}/metainfo
%{_bindir}/%{name}
%{_datadir}/applications/com.github.%{name}.desktop
%{_datadir}/autostart/com.github.%{name}.desktop.autostart
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/metainfo/com.github.%{name}.appdata.xml

%files -n librssguard-devel
%{_includedir}/lib%{name}
%{_libdir}/pkgconfig/%{name}.pc

%files -n lib%{name}-%{libver}
%{_libdir}/lib%{name}-%{version}.so

%changelog
* Mon Apr 12 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.9.2
  Fixed/changed:
  * Fixed main app window behavior when it is maximized and
    article is opened in external web browser.
  * Google Reader API plugin now correctly synchronizes changed
    messages back to server.
* Tue Apr  6 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.9.1
  Fixed/changed:
  * Properly accept all HTTP redirections, this was regression
    and is now fixed.
  * Fix repeated overwriting of messages due to bad
    UTC/localtime article timezone handling.
  * Alternating list background colors are now better suited for
    foreground text visibility.
  * Re-gaining focus after external browser was opened is now
    optional.
  * Small fixes for  "Message filters" dialog.
  * Fixed windows hiding problem when tray icon is enabled.
  * Better favicon downloading strategy which works much much
    better than previous one.
* Wed Feb 24 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.9.0
  Added:
  * Feedly support.
    https://github.com/martinrotter/rssguard/blob/master/resources/docs/Documentation.md#feedly
  * Google Reader API support, tested with many services like
    The Old Reader, Bazqux, Reedah, FreshRSS.
    https://github.com/martinrotter/rssguard/blob/master/resources/docs/Documentation.md#google-reader-api
  * Liferea-like Website scraping and feed post-processing.
    https://github.com/martinrotter/rssguard/blob/master/resources/docs/Feed-formats.md#websites-scraping-and-related-advanced-features
  * Internal web browser now offers a button which opens loaded
    webpage in external web browser.
  * Per account proxy support.
  * Display feed's icon in "is read" message list column. This
    is switchable in settings.
  * User now can sort via "id" column in a numeric way in
    message list.
  * Minimum interval for feed auto-updates is now 1 minute, not
    3 minutes like before.
  * Added some new localizations, "pt_BR" and others. Thank you,
    translators, for your hard work.
  Fixed/changed:
  * This CHANGELOG is now written in Markdown.
  * Simplified "account" dialogs.
  * Use DuckDuckGo online favicon source as fallback when
    fetching feed icons.
  * Properly disable adding/editing/deleting of synchronized
    tags/labels on some accounts.
  * RSS Guard can now be added to "favorites" on Linux/Gnome.
  * Remove "feed auto-update started" notification.
  * Some improvements of network behavior in Inoreader plugin.
  * OAuth listeners now has default post "14488".
  * Fix some deployment issues on Windows.
  * Follow HTTP/301 redirection more properly for some feeds.
  * Fixed some weird behaviors of OAuth listener.
  * All dirty account's not synchronized data are now
    synchronized when editing account.
  * All console output now sent to "std:err". Also new "-n"
    switch to disable all console outputs.
  * Some refactoring for deployment process, build packages now
    have all names according to RSS Guard installers naming
    convention.
  * Some major refinements for AdBlock which now has:
    + fixed of adding of custom rules,
    + better UX in some dialogs,
    + fully working site-wide blocking with proper error pages,
    + working element hiding rules,
    + removed some redundant and obsolete code.
- Refreshed rssguard-3.8.0-add_library_version.patch as
  rssguard-3.9.0-add_library_version.patch
* Tue Jan  5 2021 aloisio@gmx.com
- Update to version 3.8.4
  Added:
  * Dialog for message filters management now allows you to:
    + Preview your message filter by running it against COPIES
    of stored messages.
    + Run your message filter against ORIGINALS of already
    stored messages.
    + Create message filters based on single message data.
  * Toolbars in message previewer now can be hidden.
  * Number of unread messages seen in tray icon can now be
    disabled.
  Fixed/changed:
  * "Edit feed" dialog was rewritten and made modular so that it
    fits better all plugins.
  * Users now can tweak auto-update policies for feeds of all
    account types.
  * Tweaked logic of loading feed's messages to make it all work
    with some broken feeds
  * RSS Guard now prefers to use desktop environment's icon.
  * Make loading of feed's icons work better.
  * Fixed repeated overwriting of same message downloaded from
    Nextcloud News server.
  * Feed sorting is correctly case insensitive.
  * Cached message states are now far more reliably pushed back
    to server.
* Mon Nov 30 2020 aloisio@gmx.com
- Update to version 3.8.3
  Added:
  * Initial Qt 6 support.
  * When you run "open source article externally" action, then
    RSS Guard window regains focus again.
  Fixed/changed:
  * Fixed URL not passed to custom external web browser.
* Sat Nov 21 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.8.2
  * Fixed "reset" notification signal when editing toolbars in
    settings.
* Fri Nov 20 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.8.1
  Added:
  * New applications icons.
  * Added some documentation related to message filters and some
    other parts of the application:
    https://github.com/martinrotter/rssguard/blob/master/resources/docs/Documentation.md#documentation
  * Add switchable action to automatically expand categories
    when selected.
  * Added basic CLI with some basic options, run "rssguard
  - -help" to see them.
  * Ability to run multiple instance of RSS Guard at the same
    time, can be activated via CLI.
  * Ability to specify custom user data folder, can be activated
    via CLI.
  * Finnish translation.
  * Greatly enhanced user experience for authors of message
    filters. See the documentation: enums for accepting/rejecting
    of messages are now directly calleable via their names.
  Fixed/changed:
  * Handles separating feeds list, messages list and message
    viewer has now better color in default skin.
  * Now only titles of messages are sanitized before they are
    passed to message filters. Message content is left intact.
  * Nextcloud News: Do not use obsolete API endpints.
  * Nextcloud News: Support newest API breaking changes
    regarding "parent categories".
  * Partially fixed behavior of statusbar, which did not respect
    new settings for order of its buttons.
  * Use "cout" instead of "wcout" for debugging outputs.
  * Do not escape empty strings when sanitizing messages.
* Tue Nov 10 2020 aloisio@gmx.com
- Update to version 3.8.0
  Added:
  * Support for labels:
    + Labels are even synchronizable for Inoreader and TT-RSS.
    + Each message can have assigned multiple labels.
    + Feed's view now offers "Labels" folder with handy
    per-label filtering.
    + Labels assigned in message are now even available in
    message filtering.
    + You can assign arbitrary color to each of your labels.
  * Numix is now default icon theme.
  * Built-in web-base message viewer now uses mini.css
    (https://minicss.org) instead of Bootstrap. This will make
    viewing of messages quite faster while being more
    lightweight.
  * Message body now has "auto" reading direction - enhances
    support for RTL messages.
  * JSON feeds (https://www.jsonfeed.org) are now supported.
  * Added basic CLI interface, run "rssguard --help" to see its
    API overview.
  * Message view header context menu now uses non-closable menu
    for column show/hide operations.
  * Background color of rows in feed/message list can now be
    alternated.
  * Message titles are now properly sanitized before messages
    are processed by message filters.
  * There is a new documentation
    (https://github.com/martinrotter/rssguard/blob/master/resources/docs/Documentation.md#documentation)
  Fixed/changed:
  * Correct icons are now downloaded when fetching metadata for
    RSS/ATOM/JSON feeds.
  * Fixed crash when clearing contents of statusbar.
  * Translations synchronized.
  * Message previwers were completely overhauled to support
    displaying of (active) labels.
  * Codebase of web-based and text-based message previwers was
    unified, they now share all common code.
  * Some fixes for message filtering mechanism.
  * Scroll position within message viewer is now remembered if
    message gets reloaded.
  * Text-based message viewer now handles newlines better.
  * Fixed OPML export/import for some feeds/categories which
    could be skipped due to various specific errors.
  * Synchronization logic for "feeds" is now more universal,
    resulting in better behavior when running "Sync in" actions.
  * Obsolete Qt-related code removed/replaced.
  * Source code does not use hardcoded GUI colors anymore. They
    are fetched from active skin instead, making some texts more
    readable and GUI more consistent.
  * Fixed various MySQL-related problems and errors which
    rendered MySQL DB backend unusable for many users.
  * Icon themes are not bundled on Linux anymore, RSS Guard
    fully relies on system-wide themes now.
  * Big thanks to ttrss.info for providing Tiny Tiny RSS account
    for testing.
- Rebased rssguard-3.6.3-add_library_version.patch as
  rssguard-3.8.0-add_library_version.patch
* Tue Sep  1 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.7.2
  Added:
  * Parent item/folder in add category/feed dialog is now
    correctly preselected according to current feed's list
    selection.
  * Icons of parent item/folder are now correctly displayed in
    add feed/category dialogs.
  * Ability to update only feeds with custom auto-update policy
    set.
  * Enhanced feed's list context menus, now displays "Add
    feed/category here".
  Fixed/changed:
  * Fixed build on ARM machines.
- Dropped fix-mimesis-for-arm.patch (merged upstream)
* Tue Sep  1 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix build on %%arm and aarch64:
  * fix-mimesis-for-arm.patch
* Tue Aug 25 2020 aloisio@gmx.com
- Update to version 3.7.1
  Added:
  * Gmail plugin is now able to send e-mail messages and also
    reply to them.
  * Branch arrows in feeds list can now be displayed.
  * Changes in read/important field in a message from a message
    filter are now synced back to online services.
  * Filterin mechanism now accepts constants named "MSG_ACCEPT"
    and "MSG_IGNORE" which can be used instead of hardcoded
    values "1" and "2".
  Fixed/changed:
  * Message previewers now more correctly convert ASCII newlines
    to HTML line breaks to ensure better readability of message
    contents.
  * Localizations updated.
  * Accented characters now correctly decoded for Inoreader.
  * Fixed decoding of attachment URLs in messages.
  * Gmail API usage migrated to correct "batch" endpoints.
  * Crash in message filters window.
  * Some files were not downloaded correctly via internal
    downloader
  * OAuth handler was rewritten and is now able to listen on
    arbitrary destination port.
  * C++ 11 code base refactorings.
* Mon Jul 13 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.7.0
  Added:
  * Fully scriptable MESSAGE FILTERING:
    + Is avaialble for all accounts, including TT-RSS,
    Inoreader, etc.
    + Is fully scriptable with JavaScript.
    + Almost all attributes of every single message are
    changeable.
    + You can assign the same filter to multiple feeds.
    + There is a special JavaScript function which allows you to
    check if message is "duplicate".
    + There is a simple dialog for creating and testing filters.
    + Filters are automagically applied when new messages are
    downloaded.
    + See dialog accessible from menu "Messages -> Message
    filters".
    + Note that this feature is highly experimental, report
    bugs, please.
    + For more information, see
    https://github.com/martinrotter/rssguard/wiki/Message-filtering
  * Delay for first automatic feed update after application
    launch is now configurable and defaults to smaller value.
  * It is now possible to download UNREAD messages ONLY for
    TT-RSS and Nextcloud News accounts. See settings dialog for
    each respective account.
  * All accounts now offer "Important message" node in feed's
    list which allows you to elegantly display all important
    messages you have.
  * Message list is now able to show UNREAD messages only, see
    "Messages" menu. Setting is persistent.
  * RSS parser now partially supports M-RSS.
  Fixed/changed:
  * Localizations updated.
  * Show correct DB size for MariaDB in DB cleanup dialog.
  * Sorting in feed's list is now case insensitive.
  * Fixed couple of crashes when saving in-memory SQLite
    databases to persistent file.
  * Simplified code for OAuth2.0 flow, removed WebEngine-based
    solution entirely, rely on system web browser to handle the
    challenge.
  * Fixed mouse selections in message's list when "keep
    selection in center" setting is enabled.
  * Feed updating logic was rewritten and now should be more
    reliable.
  * Some obsolete code removed and refactored.
  * Purging of messages wasn't purgin important messages if
    chosen, now fixed.
  * Fixed errors in internal SQL code when displaying empty
    message list.
- Drop rssguard-3.6.3-fix_sizeof.patch (merged upstream)
* Wed Jun  3 2020 aloisio@gmx.com
- Update to version 3.6.3
  Fixed/changed:
  * Fixed some compiler warnings.
  * Fixed application crash when doing some network operations
    when application exits.
  * Some localizations now have more precise country codes.
    Localizations were also synced.
- Replace rssguard-3.6.0-add_library_version.patch with
  rssguard-3.6.3-add_library_version.patch
- Add rssguard-3.6.3-fix_sizeof.patch
* Thu May  7 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.6.1
  * Translations synced.
  * Big code refactoring, fixed almost all usages of Qt deprecated
    code.
- Drop rssguard-3.6.0-fix_no_return_nonvoid.patch (merged
  upstream)
* Thu Apr 30 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.6.0
  Added:
  * UK, GL translation and some other localizations.
  * Executable is now separated from library, making it possible
    to write external plugins for RSS Guard and distribute them
    separately as dll/lib/so/dylib file.
  * Fetch some M-RSS metadata when downloading RSS feeds.
  * Ability to postpone updates if main window is visible.
  * Switchable monochrome tray icons.
  * Default system icon theme is now default for RSS Guard on
    all platforms.
  * QtWebEngine-based RSS Guard variant now should respect web
    proxy set in settings.
  Fixed/changed:
  * Feeds.url attribute in MySQL storage now has <=1000 length.
  * Message viewer now responds to "zoom" action via mouse wheel
    + CTRL key and persistently saves the zoom level fixing the
    problem with small text in HIDPI screens.
  * Minimum Qt version is now 5.9.0.
  * Translations synced with newest strings.
  * TT-RSS: Saving of message states now works
    (read/unread/important).
  * Many code cleanups, refactorings and regressions fixed.
  * Tray icon now shows correct number of unread messages upon
    app startup.
  * Many fixes for build scripts for dev builds.
- Refreshed rssguard-3.5.2-fix_no_return_nonvoid.patch as
  rssguard-3.6.0-fix_no_return_nonvoid.patch
- Dropped rssguard-3.5.9-Qt59.patch (merged upstream)
- Added rssguard-3.6.0-add_library_version.patch
- Dropped Group tag
* Thu Sep  5 2019 Luigi Baldoni <aloisio@gmx.com>
- Disable LTO
* Thu Jun  6 2019 aloisio@gmx.com
- Add rssguard-3.5.9-Qt59.patch to fix build on Leap
* Tue Jun  4 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.5.9
  * Font in message and feed lists is now changeable, including
    its size. (#187)
  Fixed:
  * Broken backward compatibility to Qt 5.7.
* Fri May 31 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.5.8
  Added:
  * Image placeholders can now be completely disabled in
    "nowebengine" RSS Guard variant. (#205)
  Changed:
  * Source code refactored, faster regexp-related operations.
  * Optimized displaying of messages which do not have any
    associated URLs.
  Fixed:
  * "optimize tables" command for MariaDB now works correctly.
  * Fixed downloading of e-mail attachments in Gmail plugin.
  * Parsing of datetime strings now works better with Gmail
    plugin.
  * Corrected logic of cleaning DB, which allows to really get
    rid of all messages stored in DB.
  * Fixed crash when closing settings dialog.
  * Message datetime decoded correctly in Gmail plugin.
  * I hope, that appveyor/travis CI are now fixed as well.
* Thu Apr  4 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.5.7
  Added:
  * "Default" icons of feeds/categories are now NOT directly
    stored in RSS Guard DB and they are dynamically loaded from
    active icon theme instead. (#200)
  Fixed:
  * Feeds that fail to update are now correctly shown in red.
  * Newspaper mode is now correctly opened when clicked on "Open
    feed in newspaper mode" context menu item.
  * Built-in skins now properly embed HTML of displayed messages
    and no HTML "underflowing" is visible.
  * Icons are now installed to proper folders under Linux.
  * Correct "desktop" file filename.
  * Qt translations are now correctly loaded.
  * Crash related to feed update to be finished in worker thread.
  Changed:
  * Default size of main window and sizes of its widgets are now
    edited and when app is launched for the first time it just
    looks better.
  * Default width of columns in message view is now unified with
    feeds view.
  * Qt translations are now dynamically compiled and not
    hard-coded.
  * Synced translations.
  * Enhanced behavior of "Select next/previous item" in feed's
    list.
* Mon Feb 26 2018 aloisio@gmx.com
- Update to version 3.5.6
  Fixed:
  * Some minor stuff fixes.
  * Unnecessary "Welcome" notifications. (bug #176)
  * Bad handling of null/empty strings when inserting messages
    into DB. (bug #169)
  * Bad conversion of "created on" date/time in TT-RSS plugin.
    (bug #172)
  * Missing obligatory attribute in OPML 2.0 files. (bug #166)
* Sun Nov 19 2017 aloisio@gmx.com
- Update to version 3.5.5
  Added:
  * Internal message web viewer (and also lighter message text
    viewer) now support (#63) text searching. How to use:
    + Select some messages, it now gets displayed in internal
    viewer.
    + Give focus to internal viewer (click somehwere in it).
    + Press standard "find" keyboard shortcut (CTRL+F on Windows).
    + Search box appears on the bottom if internal message
    previewer.
  * New context menu internal web viewer action to open links in
    ext. browser (#80)
  * New bindable menu action Messages -> Enable message preview,
    which can disable opening message preview in internal web
    viewer. (#141)
  Fixed:
  * Displaying correct update files. (#155)
* Tue Nov  7 2017 aloisio@gmx.com
- Added AGPL-3.0+ license for QOAuth sources
* Mon Oct 23 2017 aloisio@gmx.com
- Update to version 3.5.4
  Fixed:
  * First item in itemviews is now selected when focus is gained.
    (#142)
  * Some feed files do not have URLs of messages properly
    sanitized. Strip "\n" and "\t" from URls. (bug #154)
* Fri Oct 20 2017 aloisio@gmx.com
- Update to version 3.5.2 (no changelog supplied)
- Added rssguard-3.5.2-fix_no_return_nonvoid.patch
* Mon Oct 16 2017 aloisio@gmx.com
- Update to version 3.5.1
  * Font size of message/feed list can now be changed. (#145)
  * Inoreader plugin can mark messages starred and accounts can be
    deleted.
  * All cached online service data are synchronously saved when
    any feed is updated.
* Tue Oct 10 2017 aloisio@gmx.com
- Update to version 3.5.0
  * All application resources (skins, icons, ...) are now compiled
    into the executable file. This allows for easier deployment.
  * "Add account" dialog is displayed when app is launched and no
    accounts exist so far.
  * New plugin for Inoreader. This is supported only in full RSS
    Guard "web-engine" version, because of web OAuth 2.0. The new
    plugins is in EXPERIMENTAL phase, expect errors and report them.
  * NextCloud plugin now allows to persistently set max number of
    messages to get downloaded per feed.
  * Added support for arbitrary external tools (settings category
    "Web browser & e-mail & proxy") which can open URLs of selected
    messages. (#136)
  * Standard account is now automatically added if RSS Guard is
    started with empty database.
  * Menu action "Select next unread message" in "Messages" menu
    now works across all feeds, so user can navigate through all
    unread messages with a sigle keyboard shortcut. (#132, #6)
  * Added two bindable menu actions (in menu "Web browser & tabs")
    which allow to cycle among tabs. (#6)
- Drop -lang subpackage since localisation is embedded in the
  executable now.
* Wed Sep  6 2017 aloisio@gmx.com
- Update to version 3.4.2
  * All (well, almost all) web-engine attributes can be
    disabled/enabled, including JS/plugins. (#57)
  * Some minor tweaks/fixes.
  * New Ad-Block feature for internal web browser. Based on Qt
    examples and QupZilla. Original license GNU GPLv3 is retained.
    (#123)
* Thu Jul 13 2017 aloisio@gmx.com
- Update to version 3.4.1
  Added:
  * Toolbar editor can reset toolbars.
  * Toolbar editor now uses iconified tool buttons.
  * Double mouse click on feed or recycle bin items in feeds list
    now opens all messages of the item in newspaper mode.
  * Columns in message list can be hidden/shown/reordered with
    context menu. (issue #115)
  * Auto-update notification is now switchable. (issue #119)
  * Messages which are not removed or restored are not instantly
    deleted from list, they are striked-through instead. This is
    more resource friendly.
  * Message list is now not reloaded when doing batch message
    operations.
  * Message list SQL queries are now fully adjustable. This will
    allow for integration of labels functionality in the future.
  * Auto-update status of feeds is now more general and complete.
    (issue #91)
  * Display feed title in list of messages. (issue #97)
  * Displayed feeds can now be sorted by multiple columns. Do you
    want to sort by author, and THEN by title? Simply click first
    "Title" column, then on "Author" column. If you hold CTRL during
    sorting, the sort is done in reverse column order.
  Changed:
  * Updating of RSS Guard now uses GitHub API. (issue #109)
  * Better ATOM/RSS parsing, respects now XML namespaces, bit
    better link parsing and other stuff. (issue #104)
  * Folder which holds SQL scripts got renamed to "sql".
  * Tweaked some conditions for determining newly "updated"
    messages in ATOM format. (issue #103)
  Fixed:
  * Fixed regression when restoring deleted messages.
  * Crash in TT-RSS plugin on application exit, when TT-RSS user
    needed to be logged out.
* Mon Mar 13 2017 aloisio@gmx.com
- Update to version 3.4.0
  Added:
  * New icons (CC 3.0 BY) inspired by the work of Dave Gandy.
  * "Cleanup database" action has now configurable shortcut.
    (issue #90)
  * Fixed #76, now user can choose to "not show the dialog
    again" when opening hyperlink from message previewer. This
    only concerns the lite version of RSS Guard which uses
    simpler text component for message previewing.
  Changed:
  * (Linux only) Primary user data/config storage is now undex
    $HOME/.config/RSS Guard. XDG_CONFIG_HOME variable is
    respected. If old user data is detected, then old user data
    path is used. Note that the location of cache is now changed
    too to $XDG_{CACHE,DATA}_HOME/RSS Guard.
  * RSS Guard now uses "_" character as localization file
    names separator. (issue #75)
  * Localizations are now placed in "translations" subfolder
    instead of "l10n" subfolder. (issue #75)
  version 3.3.8
  Fixed:
  * Percent HTML encoding is now decoded when messages are
    downloaded. (bug #83)
- Dropped rssguard-locale.patch (integrated upstream)
- Dropped rssguard-rpmlintrc
* Tue Jan 24 2017 jengelh@inai.de
- Update for description guidelines.
* Tue Jan 24 2017 aloisio@gmx.com
- Update to version 3.3.7
  Added:
  * Some localizations added & updated.
  * User now can place custom user skins in user "data"
    folder. (issue #81) See "About" dialog for the exact path.
  * User now can select if DB transactions are enabled or not.
    (bug #70) By default, DB transactions are now switched OFF,
    therefore anyone who wants better performance, must turn
    them ON in app settings.
  * MySQL database backend now requires at least version 5.5,
    DB encoding is now changed to utf8mb4 character set. (bug
    [#74])
  * Height if message attachment image is now configurable,
    defaults to 36. (issue #69)
  * All textual contents of all messages are now locally saved
    in explicit UTF-8 encoding. This is partially because of
    MySQL backend. We need to keep encoding of data sent to DB
    and encoding of DB itself in parity.
  Changed:
  * TT-RSS plugin now does NOT require service URL to be
    entered with "/api/" suffix. In other words, do not use that
    suffix now, RSS Guard will add it silently when it needs to.
  Fixed:
  * Fixed problem with strings in core being rendered
    untranslated. (bug #60)
  * Fixed problem with feed updates progress bar flickering.
    (bug #73)
  * Partially fixed problem with incorrect number of
    downloaded messages being reported. (bug #70)
- Refreshed rssguard-locale.patch
* Sat Dec  3 2016 aloisio@gmx.com
- Initial package (version 3.3.5)
